@@ -124,6 +124,7 @@ PSUBDBC=function(f1,
   ordempadronizado=data.frame(f1,f2,block,resp,response)
   resp1=resp
   organiz=data.frame(f1,f2,block,response,resp)
+  organiz$f1=factor(organiz$f1,unique(organiz$f1))
   organiz=organiz[order(organiz$block),]
   organiz=organiz[order(organiz$f2),]
   organiz=organiz[order(organiz$f1),]
@@ -728,8 +729,8 @@ PSUBDBC=function(f1,
                           rep(unique(Fator2),length(rownames(media)))),]
         graph$letra=letra
         graph$letra1=letra1
-        graph$f1=factor(graph$f1,levels = unique(Fator1))
-        graph$f2=factor(graph$f2,levels = unique(Fator2))
+        graph$f1=factor(graph$f1,levels = unique(fator1))
+        graph$f2=factor(graph$f2,levels = unique(fator2))
         if(addmean==TRUE){graph$numero=paste(format(graph$media,digits = dec), graph$letra,graph$letra1, sep="")}
         if(addmean==FALSE){graph$numero=paste(graph$letra,graph$letra1)}
         f1=graph$f1
@@ -754,16 +755,16 @@ PSUBDBC=function(f1,
           geom_text(aes(y=media+sup+
                           if(sup<0){-desvio}else{desvio},
                         label=numero),
-                    position = position_dodge(width=0.9),angle=angle.label, hjust=hjust,size=labelsize)}
+                    position = position_dodge(width=0.9),angle=angle.label, hjust=hjust,size=labelsize,family=family)}
         if(errorbar==FALSE){colint=colint+
           geom_text(aes(y=media+sup,label=numero),
-                    position = position_dodge(width=0.9),angle=angle.label, hjust=hjust,size=labelsize)}
+                    position = position_dodge(width=0.9),angle=angle.label, hjust=hjust,size=labelsize,family=family)}
         colint=colint+theme(text=element_text(size=textsize),
                             legend.position = posi,
                             axis.text = element_text(size=textsize,
-                                                     color="black"),
+                                                     color="black",family=family),
                             axis.title = element_text(size=textsize,
-                                                      color="black"))+
+                                                      color="black",family=family))+
           labs(fill=legend)
         if(angle !=0){colint=colint+theme(axis.text.x=element_text(hjust = 1.01,angle = angle))}
         if(color=="gray"){colint=colint+scale_fill_grey()}
@@ -853,7 +854,8 @@ PSUBDBC=function(f1,
                             textsize=textsize,
                             family=family,
                             DFres = num(tab.f2f1[nv1+1,1]),
-                            SSq = num(tab.f2f1[nv1+1,2]))
+                            SSq = num(tab.f2f1[nv1+1,2]),
+                            legend.title=legend)
         if(quali[1]==FALSE & quali[2]==FALSE){
           graf=list(grafico,NA)}
       }
@@ -939,7 +941,8 @@ PSUBDBC=function(f1,
                             textsize=textsize,
                             family=family,
                             DFres = num(tab.f1f2[nv2 +1, 1]),
-                            SSq = num(tab.f1f2[nv2 + 1, 2]))
+                            SSq = num(tab.f1f2[nv2 + 1, 2]),
+                            legend.title=legend)
         if(quali[1]==FALSE & quali[2]==FALSE){
           graf[[2]]=grafico
           grafico=graf}
@@ -1018,7 +1021,8 @@ PSUBDBC=function(f1,
                                   textsize=textsize,
                                   family=family,
                                   DFres = num(tab.f2f1[nv1+1,1]),
-                                  SSq = num(tab.f2f1[nv1+1,2]))
+                                  SSq = num(tab.f2f1[nv1+1,2]),
+                                  legend.title=legend)
         if(quali[1]==FALSE & quali[2]==FALSE){
           graf=list(grafico,NA)}
       }
@@ -1097,7 +1101,8 @@ PSUBDBC=function(f1,
                                   textsize=textsize,
                                   family=family,
                                   DFres = num(tab.f1f2[nv2 +1, 1]),
-                                  SSq = num(tab.f1f2[nv2 + 1, 2]))
+                                  SSq = num(tab.f1f2[nv2 + 1, 2]),
+                                  legend.title=legend)
         if(quali[1]==FALSE & quali[2]==FALSE){
           graf[[2]]=grafico
           grafico=graf}
