@@ -10,6 +10,7 @@
 #' @param experiment Numeric or complex vector with locations or times
 #' @param response Numerical vector containing the response of the experiment.
 #' @param transf Applies data transformation (default is 1; for log consider 0)
+#' @param constant Add a constant for transformation (enter value)
 #' @param norm Error normality test (\emph{default} is Shapiro-Wilk)
 #' @param homog Homogeneity test of variances (\emph{default} is Bartlett)
 #' @param homog.value Reference value for homogeneity of experiments. By default, this ratio should not be greater than 7
@@ -51,6 +52,7 @@ conjfat2dbc=function(f1,
                      experiment,
                      response,
                      transf = 1,
+                     constant = 0,
                      model=1,
                      norm = "sw",
                      homog = "bt",
@@ -60,12 +62,15 @@ conjfat2dbc=function(f1,
   sup=0.2*mean(response, na.rm=TRUE)
   requireNamespace("crayon")
   requireNamespace("ggplot2")
+  if(transf==1){resp=response+constant}else{if(transf!="angular"){resp=((response+constant)^transf-1)/transf}}
+  # if(transf==1){resp=response+constant}else{resp=((response+constant)^transf-1)/transf}
+  if(transf==0){resp=log(response+constant)}
+  if(transf==0.5){resp=sqrt(response+constant)}
+  if(transf==-0.5){resp=1/sqrt(response+constant)}
+  if(transf==-1){resp=1/(response+constant)}
+  if(transf=="angular"){resp=asin(sqrt((response+constant)/100))}
+
 
-  if(transf==1){resp=response}else{resp=(response^transf-1)/transf}
-  if(transf==0){resp=log(response)}
-  if(transf==0.5){resp=sqrt(response)}
-  if(transf==-0.5){resp=1/sqrt(response)}
-  if(transf==-1){resp=1/response}
   f1=factor(f1,unique(f1))
   f2=factor(f2,unique(f2))
   bloco=as.factor(block)
